==> ui-1.8.5-sources.jar: nanorep/nanowidget/Components/NRViewAdapter.java <==
package nanorep.nanowidget.Components;

import android.content.Context;
import android.support.annotation.NonNull;

import com.nanorep.nanoclient.Nanorep;
import com.nanorep.nanoclient.Response.NRConfiguration;

import nanorep.nanowidget.Components.AbstractViews.NRCustomChannelView;
import nanorep.nanowidget.Components.AbstractViews.NRCustomContentView;
import nanorep.nanowidget.Components.AbstractViews.NRCustomFeedbackView;
import nanorep.nanowidget.Components.AbstractViews.NRCustomLikeView;
import nanorep.nanowidget.Components.AbstractViews.NRCustomSearchBarView;
import nanorep.nanowidget.Components.AbstractViews.NRCustomSuggestionsView;
import nanorep.nanowidget.Components.AbstractViews.NRCustomTitleView;
import nanorep.nanowidget.R;
import nanorep.nanowidget.SearchViewsProvider;
import nanorep.nanowidget.interfaces.NRCustomViewAdapter;

/**
 * Created by nanorep on 28/09/2016.
 */

public class NRViewAdapter implements NRCustomViewAdapter {

    private SearchViewsProvider viewsProvider;

    public NRViewAdapter(@NonNull SearchViewsProvider viewsProvider){
        this.viewsProvider = viewsProvider;
    }

    @Override
    public NRCustomSearchBarView getSearchBar(Context context) {
        return viewsProvider.getSearchBarView(context);
    }

    @Override
    public NRCustomSuggestionsView getSuggestionsView(Context context) {
        return viewsProvider.getSuggestionsView(context);
    }

    @Override
    public NRCustomTitleView getTitleView (Context context) {
        return new NRArticleTitleView(context, viewsProvider);
    }

    @Override
    public NRCustomContentView getContentView(Context context) {
        return viewsProvider.getContentView(context);
    }

    @Override
    public NRCustomLikeView getLikeView(Context context) {
        return viewsProvider.getLikeView(context);
    }

    @Override
    public NRCustomChannelView getChannelView(Context context) {
        return viewsProvider.getChannelView(context);
    }

    @Override
    public NRCustomFeedbackView getFeedbackView(Context context) {
        return null;
    }
}

==> ui-1.9.1-sources.jar: nanorep/nanowidget/Components/NRViewAdapter.java <==
package nanorep.nanowidget.Components;

import android.content.Context;
import android.support.annotation.NonNull;

import nanorep.nanowidget.Components.AbstractViews.NRCustomChannelView;
import nanorep.nanowidget.Components.AbstractViews.NRCustomContentView;
import nanorep.nanowidget.Components.AbstractViews.NRCustomFeedbackView;
import nanorep.nanowidget.Components.AbstractViews.NRCustomLikeView;
import nanorep.nanowidget.Components.AbstractViews.NRCustomSearchBarView;
import nanorep.nanowidget.Components.AbstractViews.NRCustomSuggestionsView;
import nanorep.nanowidget.Components.AbstractViews.NRCustomTitleView;
import nanorep.nanowidget.SearchViewsProvider;
import nanorep.nanowidget.interfaces.NRCustomViewAdapter;

/**
 * Created by nanorep on 28/09/2016.
 */

public class NRViewAdapter implements NRCustomViewAdapter {

    private SearchViewsProvider viewsProvider;

    public NRViewAdapter(@NonNull SearchViewsProvider viewsProvider){
        this.viewsProvider = viewsProvider;
    }

    @Override
    public NRCustomSearchBarView getSearchBar(Context context) {
        if (viewsProvider != null) {
            return viewsProvider.getSearchBarView(context);
        } return null;
    }

    @Override
    public NRCustomSuggestionsView getSuggestionsView(Context context) {
        if (viewsProvider != null) {
            return viewsProvider.getSuggestionsView(context);
        } return null;
    }

    @Override
    public NRCustomTitleView getTitleView (Context context) {
        if (viewsProvider != null) {
            return new NRArticleTitleView(context, viewsProvider);
        } return null;
    }

    @Override
    public NRCustomContentView getContentView(Context context) {
        if (viewsProvider != null) {
            return viewsProvider.getContentView(context);
        } return null;
    }

    @Override
    public NRCustomLikeView getLikeView(Context context) {
        if (viewsProvider != null) {
            return viewsProvider.getLikeView(context);
        } return null;
    }

    @Override
    public NRCustomChannelView getChannelView(Context context) {
        if (viewsProvider != null) {
            return viewsProvider.getChannelView(context);
        } return null;
    }

    @Override
    public NRCustomFeedbackView getFeedbackView(Context context) {
        return null;
    }
}
